@@ -23,9 +23,9 @@ async def test_path_route_directory(tmp_path):
     resp = await route.get_page({"project": "my-package"})
     assert resp.status_code == 200
 
-    links = mousebender.simple.parse_archive_links(resp.text)
-    assert [link.filename for link in links] == project_files
-    assert [link.url for link in links] == [f"./{n}" for n in project_files]
+    links = mousebender.simple.from_project_details_html(resp.content, "")
+    assert [file["filename"] for file in links["files"]] == project_files
+    assert [file["url"] for file in links["files"]] == [f"./{n}" for n in project_files]
 
 
 @pytest.mark.asyncio
@@ -37,27 +37,51 @@ async def test_path_route_file(tmp_path):
     route = PathRoute(root=tmp_path, to="{project}.html")
     resp = await route.get_page({"project": "project"})
     assert resp.status_code == 200
-    assert resp.text == "<body>test content</body>"
+    assert resp.content.decode() == "<body>test content</body>"
 
 
 @pytest.mark.asyncio
 async def test_path_route_invalid(tmp_path):
-    """404 is returned if the path does not point to a file or directory.
-    """
+    """404 is returned if the path does not point to a file or directory."""
     route = PathRoute(root=tmp_path, to="does-not-exist")
     resp = await route.get_page({})
     assert resp.status_code == 404
 
 
 @pytest.mark.asyncio
-async def test_http_route(httpx_mock):
-    httpx_mock.add_response(
-        url="http://example.com/simple/package/",
-        data=b"<body>test content</body>",
-    )
+async def test_path_route_invalid_files(tmp_path):
+    """An HTML document for a local directory ignores invalid files."""
+    directory = tmp_path.joinpath("my-package")
+    directory.mkdir()
+
+    expected_project_files = [
+        "my-package-1.0.tar.gz",
+        "my_package-1.0-py2.py3-none-any.whl",
+    ]
+    project_files = [
+        *expected_project_files,
+        "my-package-invalid_version.tar.gz",
+        "my_package-..01-py2.py3-none-any.whl",
+    ]
+    for name in project_files:
+        directory.joinpath(name).touch()
+
+    route = PathRoute(root=tmp_path, to="{project}")
+    resp = await route.get_page({"project": "my-package"})
+    assert resp.status_code == 200
+
+    links = mousebender.simple.from_project_details_html(resp.content, "")
+    assert [file["filename"] for file in links["files"]] == expected_project_files
+    assert [file["url"] for file in links["files"]] == [
+        f"./{n}" for n in expected_project_files
+    ]
+
+
+@pytest.mark.asyncio
+async def test_http_route():
     route = HTTPRoute(
         root=pathlib.Path("does-not-matter"),
         to="http://example.com/simple/{project}/",
     )
     resp = await route.get_page({"project": "package"})
-    assert resp.text == "<body>test content</body>"
+    assert resp.status_code == 302
